from setuptools import setup, find_packages
import os

thelibFolder = os.path.dirname(os.path.realpath(__file__))
requirementPath = thelibFolder + '/requirements.txt'

install_requires = [] 
if os.path.isfile(requirementPath):
    with open(requirementPath) as f:
        install_requires = f.read().splitlines()


setup(
	name='imgInfo',
	version='0.3',
	description='Get all info of image in both command line and python API',
	license='Apache',
	author='Sulabh Shukla',
	author_email='sulabh9999@gmail.com',
	packages=find_packages(),
	download_url='https://github.com/sulabh9999/imgInfo',
	maintainer_email='sulabh9999@gmail.com',
	install_requires=install_requires,
	classifiers=[
		'Development Status :: 4 - Beta',
		'Topic :: Software Development :: Build Tools'
	],
	entry_points ={ 
        'console_scripts': [ 
            'imginfo = imgInfo.main:main'
        ] 
    },
    python_requires='>=3.5'
    # packages=['imgInfo']
)


import argparse
import sys
import os
from PIL import Image
import collections


def convert_byte(num):
	"""
	this function will convert bytes to MB.... GB... etc
	"""
	step_unit = 1024 # base the size

	for x in ['bytes', 'KB', 'MB', 'GB', 'TB']:
		if num < step_unit:
			return "%3.1f %s" % (num, x)
		num /= step_unit

def info(img):
	"""
	info: function to get all info from image
	"""
	try:
		im=Image.open(img)
		ImgDtls = collections.namedtuple('ImgDtls',['height','width','bands', 'size']) 
		return ImgDtls(im.height, im.width, len(im.getbands()), convert_byte(os.path.getsize(img))) 
	except IOError as e:
		print(f'Invalid image file: "{img}"')
		return None


def run(args):
	"""
	run: function to get all info from image used by parser
	"""
	imgDtls = info(args.imgName)
	if imgDtls:
		print('Image:', os.path.basename(args.imgName))
		print('Width:', imgDtls.width)
		print('Height:', imgDtls.height)
		print('Bands:', imgDtls.bands)


def main():
	if not sys.version_info >= (3, 5):
		sys.exit("ERROR: imgInfo needs Python 3.5 or later.")

	if len(sys.argv) == 1:
		print("imgInfo: imgInfo command line tools")
		print("imgInfo -h, --help")
		sys.exit()

	parser = argparse.ArgumentParser(prog='imgInfo', description='Get information abount given image file')
	parser.add_argument('imgName', help='Name of an image')
	# parser.add_argument('-s', action='store_true', help='To show image shape as tupple')
	args = parser.parse_args()
	run(args)


if __name__ == '__main__':
	main()
